@@ -104,6 +104,7 @@
     rust_2018_idioms,
     rust_2018_compatibility
 )]
+use attohttpc::{Method, RequestBuilder};
 use kuchiki::{
     parse_html, traits::TendrilSink, ElementData, Node, NodeDataRef, NodeRef, Specificity,
 };
@@ -114,12 +115,7 @@ mod parser;
 use ahash::AHashMap;
 pub use error::InlineError;
 use smallvec::{smallvec, SmallVec};
-use std::{
-    borrow::Cow,
-    collections::hash_map::Entry,
-    fs::File,
-    io::{Read, Write},
-};
+use std::{borrow::Cow, collections::hash_map::Entry, fs, io::Write};
 pub use url::{ParseError, Url};
 
 /// Configuration options for CSS inlining process.
@@ -323,15 +319,14 @@ impl<'a> CSSInliner<'a> {
                 .select("link[rel~=stylesheet]")
                 .map_err(|_| error::InlineError::ParseError(Cow::from("Unknown error")))?
                 .filter_map(|link_tag| link_tag.attributes.borrow().get("href").map(str::to_string))
+                .filter(|link| !link.is_empty())
                 .collect::<Vec<String>>();
             links.sort_unstable();
             links.dedup();
             for href in &links {
-                if !href.is_empty() {
-                    let url = self.get_full_url(href);
-                    let css = load_external(url.as_ref())?;
-                    process_css(&document, css.as_str(), &mut styles);
-                }
+                let url = self.get_full_url(href);
+                let css = load_external(url.as_ref())?;
+                process_css(&document, css.as_str(), &mut styles);
             }
         }
         if let Some(extra_css) = &self.options.extra_css {
@@ -388,15 +383,13 @@ impl<'a> CSSInliner<'a> {
     }
 }
 
-fn load_external(url: &str) -> Result<String> {
-    if url.starts_with("http") | url.starts_with("https") {
-        let response = attohttpc::get(url).send()?;
+fn load_external(location: &str) -> Result<String> {
+    if location.starts_with("https") | location.starts_with("http") {
+        let request = RequestBuilder::try_new(Method::GET, location)?;
+        let response = request.send()?;
         Ok(response.text()?)
     } else {
-        let mut file = File::open(url)?;
-        let mut css = String::new();
-        file.read_to_string(&mut css)?;
-        Ok(css)
+        fs::read_to_string(location).map_err(InlineError::IO)
     }
 }
 
