@@ -1,22 +1,7 @@
+#[macro_use]
+mod utils;
 use css_inline::{inline, CSSInliner, InlineOptions, Url};
 
-macro_rules! html {
-    ($style: expr, $body: expr) => {
-        format!(
-            r#"<html><head><title>Test</title><style>{}</style></head><body>{}</body></html>"#,
-            $style, $body
-        )
-    };
-}
-
-macro_rules! assert_inlined {
-    (style = $style: expr, body = $body: expr, expected = $expected: expr) => {{
-        let html = html!($style, $body);
-        let inlined = inline(&html).unwrap();
-        assert_eq!(inlined, html!($style, $expected))
-    }};
-}
-
 #[test]
 fn no_existing_style() {
     // When no "style" attributes exist
@@ -365,6 +350,19 @@ h2 { color: red; }
     ))
 }
 
+#[test]
+fn remote_network_stylesheet_invalid_url() {
+    let html = r#"
+<html>
+<head>
+<link href="http:" rel="stylesheet" type="text/css">
+</head>
+<body>
+</body>
+</html>"#;
+    assert!(inline(html).is_err());
+}
+
 #[test]
 fn remote_network_stylesheet_same_scheme() {
     let html = r#"
